@@ -140,9 +140,9 @@ static int
 debug_pixbuf_viewer_expose_event (GtkWidget *widget, GdkEventExpose *event)
 {
  	DebugPixbufViewer *viewer;
-	ArtIRect clipped_dirty_area;
-	ArtIRect dirty_area;
-	ArtIRect bounds;
+	EelIRect clipped_dirty_area;
+	EelIRect dirty_area;
+	EelIRect bounds;
 
 	g_return_val_if_fail (DEBUG_IS_PIXBUF_VIEWER (widget), TRUE);
 	g_return_val_if_fail (event != NULL, TRUE);
@@ -161,15 +161,15 @@ debug_pixbuf_viewer_expose_event (GtkWidget *widget, GdkEventExpose *event)
 	bounds.y1 = bounds.y0 + gdk_pixbuf_get_height (viewer->pixbuf);
 	
 	/* Clip the dirty area to the screen; bail if no work to do */
-	dirty_area = eel_gdk_rectangle_to_art_irect (event->area);
+	dirty_area = eel_gdk_rectangle_to_eel_irect (event->area);
 	clipped_dirty_area = eel_gdk_window_clip_dirty_area_to_screen (event->window,
 								       dirty_area);
-	if (!art_irect_empty (&clipped_dirty_area)) {
-		ArtIRect clipped_bounds;
+	if (!eel_irect_is_empty (&clipped_dirty_area)) {
+		EelIRect clipped_bounds;
 
-		art_irect_intersect (&clipped_bounds, &bounds, &clipped_dirty_area);
+		eel_irect_intersect (&clipped_bounds, &bounds, &clipped_dirty_area);
 
-		if (!art_irect_empty (&clipped_bounds)) {
+		if (!eel_irect_is_empty (&clipped_bounds)) {
 			g_assert (clipped_bounds.x0 >= bounds.x0);
 			g_assert (clipped_bounds.y0 >= bounds.y0);
 			
@@ -215,24 +215,32 @@ debug_pixbuf_viewer_set_pixbuf (DebugPixbufViewer *viewer, GdkPixbuf *pixbuf)
  */
 void
 eel_debug_draw_rectangle_and_cross (GdkDrawable *drawable,
-				    ArtIRect rectangle,
+				    EelIRect rectangle,
 				    guint32 color,
 				    gboolean draw_cross)
 {
 	GdkGC *gc;
+	GdkColor color_gdk = { 0 };
 
 	int width;
 	int height;
 
 	g_return_if_fail (drawable != NULL);
-	g_return_if_fail (!art_irect_empty (&rectangle));
+	g_return_if_fail (!eel_irect_is_empty (&rectangle));
 
 	width = rectangle.x1 - rectangle.x0;
 	height = rectangle.y1 - rectangle.y0;
 
  	gc = gdk_gc_new (drawable);
  	gdk_gc_set_function (gc, GDK_COPY);
-	gdk_rgb_gc_set_foreground (gc, color);
+	
+	color_gdk.red   = ((color >> 16) & 0xff) << 8;
+	color_gdk.green = ((color >>  8) & 0xff) << 8;
+	color_gdk.blue  = ((color      ) & 0xff) << 8;
+	gdk_colormap_alloc_color (
+		gdk_drawable_get_colormap (drawable),
+		&color_gdk, FALSE, FALSE);
+	gdk_gc_set_rgb_fg_color (gc, &color_gdk);
 	
 	gdk_draw_rectangle (drawable,
 			    gc,
@@ -330,7 +338,7 @@ destroy_debug_window (void)
  * Show the given pixbuf in an in process window.
  */
 void
-eel_debug_show_pixbuf (const GdkPixbuf *pixbuf)
+eel_debug_show_pixbuf (GdkPixbuf *pixbuf)
 {
 	if (debug_window == NULL) {
 		GtkWidget *vbox;
@@ -356,7 +364,7 @@ eel_debug_show_pixbuf (const GdkPixbuf *pixbuf)
 	}
 
 	gtk_widget_show (debug_window);
-	debug_pixbuf_viewer_set_pixbuf (DEBUG_PIXBUF_VIEWER (debug_image), (GdkPixbuf *) pixbuf);
+	debug_pixbuf_viewer_set_pixbuf (DEBUG_PIXBUF_VIEWER (debug_image), pixbuf);
 
 	gdk_window_clear_area_e (debug_window->window, 0, 0, -1, -1);
 }
