@@ -107,7 +107,7 @@ eel_check_boolean_result (gboolean result, gboolean expected)
 }
 
 void
-eel_check_rectangle_result (ArtIRect result,
+eel_check_rectangle_result (EelIRect result,
 			    int expected_x0,
 			    int expected_y0,
 			    int expected_x1,
@@ -149,7 +149,7 @@ eel_check_dimensions_result (EelDimensions result,
 }
 
 void
-eel_check_point_result (EelArtIPoint result,
+eel_check_point_result (EelIPoint result,
 			int expected_x,
 			int expected_y)
 {
@@ -207,32 +207,6 @@ eel_check_string_result (char *result, const char *expected)
 	eel_after_check ();
 }
 
-void
-eel_check_string_list_result (EelStringList *result,
-			      const char *expected_value,
-			      const char *expected_value_delimiter)
-{
-	int i;
-	char *result_as_string;
-
-	g_return_if_fail (expected_value_delimiter != NULL);
-
-	while (1) {
-		i = eel_string_list_get_index_for_string (result, "");
-		if (i == EEL_STRING_LIST_NOT_FOUND) {
-			break;
-		}
-		eel_string_list_modify_nth (result, i, "<empty string>");
-	}
-
-	result_as_string = eel_string_list_as_string (result,
-						      expected_value_delimiter,
-						      EEL_STRING_LIST_ALL_STRINGS);
-	eel_string_list_free (result);
-
-	eel_check_string_result (result_as_string, expected_value);
-}
-
 void
 eel_before_check_function (const char *name)
 {
